@@ -1,11 +1,12 @@
 package Class::MOP::Object;
-$Class::MOP::Object::VERSION = '2.1213';
+our $VERSION = '2.2009';
+
 use strict;
 use warnings;
 
 use parent 'Class::MOP::Mixin';
 use Scalar::Util 'blessed';
-use Module::Runtime 'use_module';
+use Module::Runtime;
 
 # introspection
 
@@ -114,7 +115,7 @@ Class::MOP::Object - Base class for metaclasses
 
 =head1 VERSION
 
-version 2.1213
+version 2.2009
 
 =head1 DESCRIPTION
 
@@ -124,25 +125,21 @@ This class is a very minimal base class for metaclasses.
 
 This class provides a few methods which are useful in all metaclasses.
 
-=over 4
-
-=item B<< Class::MOP::???->meta >>
+=head2 Class::MOP::???->meta
 
 This returns a L<Class::MOP::Class> object.
 
-=item B<< $metaobject->dump($max_depth) >>
+=head2 $metaobject->dump($max_depth)
 
 This method uses L<Data::Dumper> to dump the object. You can pass an
 optional maximum depth, which will set C<$Data::Dumper::Maxdepth>. The
 default maximum depth is 1.
 
-=item B<< $metaclass->throw_error($message) >>
+=head2 $metaclass->throw_error($message)
 
 This method calls L<Class::MOP::Mixin/_throw_exception> internally, with an object
 of class L<Moose::Exception::Legacy>.
 
-=back
-
 =head1 AUTHORS
 
 =over 4
@@ -191,7 +188,7 @@ Matt S Trout <mst@shadowcat.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
