@@ -1,8 +1,8 @@
 package Moose::Exception;
-our $VERSION = '2.1804';
+our $VERSION = '2.2009';
 
 use Moose;
-use Devel::StackTrace 1.33;
+use Devel::StackTrace 2.03;
 
 has 'trace' => (
     is            => 'ro',
@@ -36,7 +36,8 @@ sub _build_trace {
     # be weakening all references in its frames)
     my $skip = 0;
     while (my @c = caller(++$skip)) {
-        last if $c[3] =~ /^(.*)::new$/ && $self->isa($1);
+        last if ($c[3] =~ /^(.*)::new$/ || $c[3] =~ /^\S+ (.*)::new \(defined at /)
+            && $self->isa($1);
     }
     $skip++;
 
@@ -91,6 +92,7 @@ sub as_string {
     return $message;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 # ABSTRACT: Superclass for Moose internal exceptions
@@ -107,7 +109,7 @@ Moose::Exception - Superclass for Moose internal exceptions
 
 =head1 VERSION
 
-version 2.1804
+version 2.2009
 
 =head1 DESCRIPTION
 
